/*config.c - By Luke Sheneman 1992 
Copyright (c) 1992 Luke Sheneman
Copyright (c) 1992 University of Idaho, Moscow, Idaho.

Permission to use, copy, modify, and distribute this software and its
documentation free of charge for any purpose is hereby granted without
fee, provided that the above copyright notices appear in all copies and
that both those copyright notices and this permission notice appear in
supporting documentation, and that neither the name of the University of
Idaho nor the name of Luke Sheneman be used in advertising or publicity
pertaining to distribution of the software without specific, written
prior permission from both parties.  Neither The University of Idaho
nor Luke Sheneman make any representations about the suitability of
this software for any purpose.  It is provided "as is" without express
or implied warranty.

THE UNIVERSITY OF IDAHO AND LUKE SHENEMAN DISCLAIM ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS.  IN NO EVENT SHALL THE UNIVERSITY OF IDAHO
OR DEAN COLLINS BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
THIS SOFTWARE.
*/

#include <stdio.h>
#include "zdbm.h"
#include "cloud.h"
#include "config.h"



/*
______________________________________________________________________
AddPath()

FUNCTION DESCRIPTION:
	This function adds a problem path (aka problem types) to a
linked list of paths.
______________________________________________________________________
REVISION HISTORY:
     Author:  Luke Sheneman 			Date:
     Documentation Enhancement: Dean Collins	Date: 3/27/93
______________________________________________________________________
*/



struct Full_path *AddPath(head,path)
struct Full_path *head;
char *path;

     /* Interface description:
         INPUT:
	  head - head of problem types linked list (NULL if empty)
	  path - path to add to list
         OUTPUT:
          None.
         RETURN VALUE:
          struct Full_path * - head of (possibly new) list.
     */
      
{
     /* Internal variables: */
          /* Major */
          /* NONE */
          /* Minor */
          /* NONE */



   /*------------------ Start of AddPath() routine -------------------*/

		/* if head is NULL, allocate memory for a Full_path element,
                 * put path in head->path, and set head->next to be NULL.
                 */
        if(!head)
        {
                head=(struct Full_path *)malloc(sizeof(struct Full_path));
                strcpy(head->path,path);
                head->next=NULL;
#ifdef DEBUG
		printf("AddPath(): pathA='%s' =? '%s'\n",path,head->path) ;
#endif
        }

		/* Otherwise, find the end of the list, allocate memory
		 * for a Full_path element, put path in its path field
		 * set its next field to be NULL, and set the next
		 * field of the last element in the list to be the
		 * new element.
                 */
	else
	{
		struct Full_path *t,*temp;
		
		t=head;
		while(t->next)
			t=t->next;
		temp=(struct Full_path *)malloc(sizeof(struct Full_path));
		strcpy(temp->path,path);
		temp->next=NULL;
		t->next=temp;	
#ifdef DEBUG
		printf("AddPath(): pathB='%s' =? '%s'\n",path,t->path) ;
#endif
	}
	return(head);
}  /*---------------------- End of AddPath() -------------------------*/


/*
______________________________________________________________________
MailInfo()

FUNCTION DESCRIPTION:
        This function adds a mail record to a linked list of these
records.
______________________________________________________________________
REVISION HISTORY:
     Author:  Luke Sheneman			Date:
     Documentation Enhancement: Dean Collins	Date: 3/27/93
______________________________________________________________________
*/



MailInfo *AddMail(head,username,days)
MailInfo *head;
char *username;
int days;

     /* Interface description:
         INPUT:
          head	   - The head of the linked list of mail records.
	  username - The user to add to the list.
	  days     - The corresponding number of days to add.
         OUTPUT:
          None.
         RETURN VALUE:
          MailInfo * - head of (possibly new) list.
     */
      
{
     /* Internal variables: */
          /* Major */

          /* Minor */


   /*----------------- Start of MailInfo() routine ------------------*/

                /* if head is NULL, allocate memory for a MailInfo element,
                 * put username in head->username, days in head->days,
                 * and set head->next to be NULL.
                 */
	if(!head)
        {
                head=(MailInfo *)malloc(sizeof(MailInfo));
		strcpy(head->username,username);
		head->days=days;
                head->next=NULL;
        }
                /* Otherwise, find the end of the list, allocate memory
                 * for a MailInfo element, put username in its username field,
                 * days in its days field, set its next field to be NULL,
		 * and set the next field of the last element in the list
		 * to be the new element.
                 */
        else
        {
                MailInfo *t,*temp;

                t=head;
                while(t->next)
                        t=t->next;
                temp=(MailInfo *)malloc(sizeof(MailInfo));
                strcpy(temp->username,username);
		temp->days=days;
                temp->next=NULL;
		t->next=temp;
        }
        return(head);

}  /*--------------------- End of MailInfo() ------------------------*/

/* End of config.c */
