/* Author:  Luke Sheneman  */

/*
 * Copyright (c) 1992 University of Idaho, Moscow, Idaho.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation free of charge for any purpose is hereby granted without
 * fee, provided that the above copyright notice appear in all copies and
 * that both that copyright notice and this permission notice appear in
 * supporting documentation, and that the name of the University of Idaho
 * not be used in advertising or publicity pertaining to distribution of
 * the software without specific, written prior permission.  The University
 * of Idaho makes no representations about the suitability of this software
 * for any purpose.  It is provided "as is" without express or implied warranty.
 *
 * THE UNIVERSITY OF IDAHO DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS.
 * IN NO EVENT SHALL THE UNIVERSITY OF IDAHO BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
 * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
 * OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THIS SOFTWARE.
 */


/* The following functions are defined in subtree.c:
 *
 * FreeParts() - frees an array of strings which was created by BreakUpPath().
 * SubTree() - returns a pointer to a subtree of the problem tree given the
 *	tree and a path to the desired tree.
 *
 */


#include <stdio.h>
#include <zdbm.h>
#include "cloud.h"
#include "clouderror.h"


void FreeParts(parts)
char *parts[MAXBRANCHES];
{
	int loop;

	cld_errno=0;

	for(loop=0;loop<MAXBRANCHES;loop++)
		free(parts[loop]);
}


ProblemTree *SubTree(tree,ppath)
ProblemTree *tree;
char ppath[DBPATHLEN];
{
        ProblemTree *subtree,*current;
        char *parts[MAXBRANCHES];
        char newpath[DBPATHLEN];
        int loop=0;

	cld_errno=0;

        current=tree;
        strcpy(newpath,ppath);
        strcat(newpath,"/");

        BreakUpPath(newpath,parts);
        if(!strcmp(parts[0],ROOTSTR))
                if(!strcmp(parts[1],""))
                        return(tree);
                else
                        loop++;

        while(strcmp(parts[loop],""))
        {
                subtree=FindBranch(current,parts[loop]);
                if(subtree)
                {
                        current=subtree;
                        loop++;
                }
                else
		{
			cld_errno=CLD_ERR34;
			FreeParts(parts);
                        return(NULL);
		}
        }
	FreeParts(parts);
        return(subtree);
}
